pub struct DecodeConfig { /* private fields */ }Trait Implementations
Sourceimpl AsRef<Options> for DecodeConfig
impl AsRef<Options> for DecodeConfig
Sourcefn as_ref(&self) -> &SerializeOptions
fn as_ref(&self) -> &SerializeOptions
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl Clone for DecodeConfig
impl Clone for DecodeConfig
Sourcefn clone(&self) -> DecodeConfig
fn clone(&self) -> DecodeConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for DecodeConfig
impl Default for DecodeConfig
Sourceimpl Deref for DecodeConfig
impl Deref for DecodeConfig
Sourceimpl From<DecodeConfig> for SerializeOptions
impl From<DecodeConfig> for SerializeOptions
Sourcefn from(value: DecodeConfig) -> Self
fn from(value: DecodeConfig) -> Self
Converts to this type from the input type.
Sourceimpl From<Options> for DecodeConfig
impl From<Options> for DecodeConfig
Sourcefn from(value: SerializeOptions) -> Self
fn from(value: SerializeOptions) -> Self
Converts to this type from the input type.
Sourceimpl FromLua for DecodeConfigwhere
Self: 'static + Clone,
impl FromLua for DecodeConfigwhere
Self: 'static + Clone,
Sourceimpl UserData for DecodeConfig
impl UserData for DecodeConfig
Sourcefn register(registry: &mut UserDataRegistry<Self>)
fn register(registry: &mut UserDataRegistry<Self>)
Registers this type for use in Lua. Read more
Sourcefn add_fields<F>(fields: &mut F)where
F: UserDataFields<Self>,
fn add_fields<F>(fields: &mut F)where
F: UserDataFields<Self>,
Adds custom fields specific to this userdata.
Sourcefn add_methods<M>(methods: &mut M)where
M: UserDataMethods<Self>,
fn add_methods<M>(methods: &mut M)where
M: UserDataMethods<Self>,
Adds custom methods and operators specific to this userdata.