pub struct EncodeConfig { /* private fields */ }Trait Implementations
Sourceimpl AsRef<Options> for EncodeConfig
impl AsRef<Options> for EncodeConfig
Sourcefn as_ref(&self) -> &DeserializeOptions
fn as_ref(&self) -> &DeserializeOptions
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl Clone for EncodeConfig
impl Clone for EncodeConfig
Sourcefn clone(&self) -> EncodeConfig
fn clone(&self) -> EncodeConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for EncodeConfig
impl Default for EncodeConfig
Sourceimpl Deref for EncodeConfig
impl Deref for EncodeConfig
Sourceimpl From<EncodeConfig> for DeserializeOptions
impl From<EncodeConfig> for DeserializeOptions
Sourcefn from(value: EncodeConfig) -> Self
fn from(value: EncodeConfig) -> Self
Converts to this type from the input type.
Sourceimpl From<Options> for EncodeConfig
impl From<Options> for EncodeConfig
Sourcefn from(value: DeserializeOptions) -> Self
fn from(value: DeserializeOptions) -> Self
Converts to this type from the input type.
Sourceimpl FromLua for EncodeConfigwhere
Self: 'static + Clone,
impl FromLua for EncodeConfigwhere
Self: 'static + Clone,
Sourceimpl UserData for EncodeConfig
impl UserData for EncodeConfig
Sourcefn register(registry: &mut UserDataRegistry<Self>)
fn register(registry: &mut UserDataRegistry<Self>)
Registers this type for use in Lua. Read more
Sourcefn add_fields<F>(fields: &mut F)where
F: UserDataFields<Self>,
fn add_fields<F>(fields: &mut F)where
F: UserDataFields<Self>,
Adds custom fields specific to this userdata.
Sourcefn add_methods<M>(methods: &mut M)where
M: UserDataMethods<Self>,
fn add_methods<M>(methods: &mut M)where
M: UserDataMethods<Self>,
Adds custom methods and operators specific to this userdata.